@@ -3,7 +3,7 @@ from multiprocessing.shared_memory import SharedMemory
 from .templates import MEMORY_NAME
 
 
-def create_shared_memmory(name: str, size: int) -> None:
+def create_shared_memory(name: str, size: int) -> None:
     SharedMemory(MEMORY_NAME.format(name=name), create=True, size=size)
 
 
